window.Gleam.initSearch([{"doc":"birdie","title":"birdie","content":"# 🐦‍⬛ Birdie - snapshot testing in Gleam\n\n[![Package Version](https://img.shields.io/hexpm/v/birdie)](https://hex.pm/packages/birdie)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/birdie/)\n![Supported targets](https://img.shields.io/badge/supports-all_targets-ffaff3)\n\nSnapshot testing allows you to perform assertions without having to write the\nexpectation yourself. Birdie will store a snapshot of the expected value and\ncompare future runs of the same test against it. Imagine doing a\n`should.equal(expected, got)` where you don&#39;t have to take care of writing the\nexpected output.\n\n## Writing snapshot tests with Birdie\n\nFirst you&#39;ll want to add the package to your dependencies:\n\n```sh\ngleam add --dev birdie\n```\n\nTo write snapshot tests you can import the `birdie` module and use the\n[`snap`](https://hexdocs.pm/birdie/birdie.html#snap) function:\n\n```gleam\nimport gleeunit\nimport birdie\n\npub fn main() {\n  gleeunit.main()\n}\n\npub fn hello_birdie_test() {\n  &quot;🐦‍⬛ Smile for the birdie!&quot;\n  |&gt; birdie.snap(title: &quot;my first snapshot&quot;)\n  // All snapshots must have a unique title!\n}\n```\n\nThis will record a new snapshot with the given title and content. A snapshot\ntest will always fail on its first run until you review and accept it.\nOnce you&#39;ve reviewed and accepted a snapshot, the test will fail only if the\nsnapshot&#39;s content changes; in that case you will be presented with a diff and\nasked to review it once again.\n\nA typical workflow will look like this:\n\n- Run your tests\n- If you have any new snapshots - or some of the snapshots have changed - some\n  tests will fail\n- Review all the new snapshots deciding if you want to keep the new version or\n  the previously accepted one\n- And don&#39;t forget to commit your snapshots! Those should be treated like\n  code and checked with the vcs you&#39;re using\n\n## Reviewing snapshots\n\nBirdie also provides a CLI tool to help you in the review process: run\n`gleam run -m birdie` in your project and birdie will help you interactively\nreview all your new snapshots.\n\n&gt; The CLI tool can also do more than just guide you through all your snapshots\n&gt; one by one. To check all the available options you can run\n&gt; `gleam run -m birdie help`\n\n![image](https://github.com/giacomocavalieri/birdie/blob/main/birdie.gif?raw=true)\n\n## FAQ\n\n### What should my snapshots be named like?\n\nA good idea is to give snapshots long descriptive titles that clearly state\nwhat you&#39;re expecting to see when reviewing those.\nAlso all snapshots _must_ have unique names so that birdie won&#39;t mix those up,\nso be careful when naming snapshots to not repeat the same title twice!\n\n&gt; During the review process, Birdie will try to be helpful and show you an\n&gt; error message if it can spot two tests that happen to share the same exact\n&gt; title. It will only work for snapshots that have a literal string as a title\n&gt; but it can be really helpful to spot some of those confusing bugs!\n\n### How big should the snapshot&#39;s content be?\n\nMy recommendation is strive to have small and cohesive snapshots. Each\nsnapshot test should test one thing and one thing only. Having small snapshots\nwill make your life way easier during the review process!\nIt&#39;s better to review 10 small snpashots than a single huge one and you&#39;ll\nsee better, more focused diffs.\n\n### Why is the snapshot content a `String`? I want to snapshot other things!\n\nBirdie will only ever accept `String` values and it&#39;s up to you to turn your\nown Gleam types into a `String` before snapping those: this way you have total\nfreedom and will be able to choose a format that makes sense to you and makes\nthings easier to review!\n\nIf you don&#39;t want to write serialisers for yourself and are ok with a default\nlook then I recommend you try using the [`pprint`](https://hexdocs.pm/pprint/)\npackage.\nIt&#39;s an awesome package that can turn any Gleam type into a pretty string that\nwill work perfectly with Birdie and produce nice diffs out of the box.\nI&#39;m sure most of the times you won&#39;t feel the need to use anything else!\n\n```gleam\nimport birdie\nimport pprint\n\npub fn a_snapshot_test() {\n  Ok([1, 2, 3])\n  |&gt; pprint.format\n  // ^^^^^^^^^^^^^\n  // pprint does all the hard work of turning\n  // any value into a pretty string!\n  |&gt; birdie.snap(title: &quot;a snapshot test using pprint&#39;s output&quot;)\n}\n```\n\n## References\n\nThis package was heavily inspired by the excellent Rust library\n[`insta`](https://insta.rs), do check it out!\n\n## Contributing\n\nIf you think there&#39;s any way to improve this package, or if you spot a bug don&#39;t\nbe afraid to open PRs, issues or requests of any kind!\nAny contribution is welcome 💜\n","url":"index.html"},{"doc":"birdie","title":"main","content":"pub fn main() -&gt; Nil\n Reviews the snapshots in the project&#39;s folder.\n This function will behave differently depending on the command line\n arguments provided to the program.\n To have a look at all the available options you can run\n `gleam run -m birdie help`.\n\n &gt; 🐦‍⬛ The recommended workflow is to first run your gleeunit tests with\n &gt; `gleam test` and then review any new/failing snapshot manually running\n &gt; `gleam run -m birdie`.\n &gt;\n &gt; And don&#39;t forget to commit your snapshots! Those should be treated as code\n &gt; and checked with the vcs you&#39;re using.\n\nSynonyms:\nbirdie.main\nbirdie main","url":"birdie.html#main"},{"doc":"birdie","title":"snap","content":"pub fn snap(content content: String, title title: String) -&gt; Nil\n Performs a snapshot test with the given title, saving the content to a new\n snapshot file. All your snapshots will be stored in a folder called\n `birdie_snapshots` in the project&#39;s root.\n\n The test will fail if there already is an accepted snapshot with the same\n title and a different content.\n The test will also fail if there&#39;s no accepted snapshot with the same title\n to make sure you will review new snapshots as well.\n\n &gt; 🚨 A snapshot is saved to a file named after its title, so all titles\n &gt; should be unique! Otherwise you&#39;d end up comparing unrelated snapshots.\n\n &gt; 🐦‍⬛ To review all your snapshots interactively you can run\n &gt; `gleam run -m birdie`.\n &gt;\n &gt; To get an help text and all the available options you can run\n &gt; `gleam run -m birdie help`.\n\nSynonyms:\nbirdie.snap\nbirdie snap","url":"birdie.html#snap"},{"doc":"birdie","title":"birdie","content":"","url":"birdie.html"}]);